#include <gnome.h>

#include "gstcontrol.h"
#include "stockicons.h"
#include "utils.h"

struct _GstControlPrivate {
	GtkWidget           *fixed;
	GtkWidget           *hbox_top;
	GtkWidget           *hbox_bot;

	GtkWidget           *button_play_bot;
	GtkWidget           *button_play_top;
	GtkWidget           *button_stop;
	GtkWidget           *button_prev;
	GtkWidget           *button_next;
	GtkWidget           *button_mute;
	GtkWidget           *button_list;
	GtkWidget           *button_fullscreen;
	GtkWidget           *button_mini_to_normal;
	GtkWidget           *button_mini;
	GtkWidget           *button_fs_to_normal;

	GObject             *adjustment_volume;
	GtkWidget           *hscale_volume;

	GObject             *adjustment_seek;
	GtkWidget           *seek_handle;
	gboolean             seek_in_progress;
	gboolean             allow_fullscreen;

	GtkWidget           *image_playing_top;
	GtkWidget           *image_playing_bot;
	GtkWidget           *image_paused_top;
	GtkWidget           *image_paused_bot;
	
	GtkWidget           *image_playlist;
	
	GtkWidget           *image_volume;
	GtkWidget           *image_volume_mute;

	GstMediaPlayMode     display_mode;
	
};

enum {
	BUTTON_PLAY,
	BUTTON_STOP,
	BUTTON_NEXT,
	BUTTON_PREV,
	BUTTON_LIST,
	BUTTON_MUTE,
	VOLUME_CHANGE,
	SEEK_CHANGE,
	DISPLAY_MODE_CHANGE,
	LAST_SIGNAL
};

static gint gst_control_signals [LAST_SIGNAL] = { 0 };

static void  gst_control_destroy   (GtkObject  *object);
static void  gst_control_finalize  (GObject    *object); 
static gint  gst_control_expose    (GtkWidget  *widget, GdkEventExpose *event);

GNOME_CLASS_BOILERPLATE (GstControl, gst_control, 
			 GtkVBox, GTK_TYPE_VBOX)

static void
gst_control_event_check (GtkWidget* widget, GstControl *control)
{
	GstControlPrivate *priv;

	g_return_if_fail(GST_IS_CONTROL(control));

	priv = control->_priv;

	if (widget == priv->button_play_top || widget == priv->button_play_bot)
	{
		g_signal_emit (control, gst_control_signals [BUTTON_PLAY], 0);
	}
	else if (widget == priv->button_stop)
	{
		g_signal_emit (control, gst_control_signals [BUTTON_STOP], 0);
	}
	else if (widget == priv->button_next)
	{
		g_signal_emit (control, gst_control_signals [BUTTON_NEXT], 0);
	}
	else if (widget == priv->button_prev)
	{
		g_signal_emit (control, gst_control_signals [BUTTON_PREV], 0);
	}
	else if (widget == priv->button_list)
	{
		g_signal_emit (control, gst_control_signals [BUTTON_LIST], 0);
	}
	else if (widget == priv->button_mute)
	{
		g_signal_emit (control, gst_control_signals [BUTTON_MUTE], 0);
	}
	else if (widget == priv->button_fullscreen)
	{
		g_signal_emit (control, gst_control_signals [DISPLAY_MODE_CHANGE], 0, GST_MEDIA_PLAY_FULLSCREEN);
	}
	else if (widget == priv->button_mini_to_normal)
	{
		g_signal_emit (control, gst_control_signals [DISPLAY_MODE_CHANGE], 0, GST_MEDIA_PLAY_NORMAL);
	}
	else if (widget == priv->button_mini)
	{
		g_signal_emit (control, gst_control_signals [DISPLAY_MODE_CHANGE], 0, GST_MEDIA_PLAY_MINI);
	}
	else if (widget == priv->button_fs_to_normal)
	{
		g_signal_emit (control, gst_control_signals [DISPLAY_MODE_CHANGE], 0, GST_MEDIA_PLAY_NORMAL);
	}
}

static void
volume_changed (GtkAdjustment *adjustment, GstControl *control)
{
	g_return_if_fail(GST_IS_CONTROL(control));
	g_signal_emit (control, gst_control_signals [VOLUME_CHANGE], 0, adjustment->value);
}

static gboolean
seek_changed (GtkWidget *widget, GdkEventButton *event, GstControl *control)
{
	g_return_if_fail(GST_IS_CONTROL(control));
	g_signal_emit (control, gst_control_signals [SEEK_CHANGE], 0, 
	               gtk_adjustment_get_value(GTK_ADJUSTMENT(control->_priv->adjustment_seek)));
	control->_priv->seek_in_progress = FALSE;
	return FALSE;
}

static gboolean
seek_started (GtkWidget *widget, GdkEventButton *event, GstControl *control)
{
	g_return_val_if_fail (GST_IS_CONTROL (control), FALSE);
	control->_priv->seek_in_progress = TRUE;
	return FALSE;
}

static void
gst_control_class_init (GstControlClass *class)
{
	GtkWidgetClass  *widget_class = (GtkWidgetClass *) class;
	GtkObjectClass  *object_class = (GtkObjectClass *) class;
	GObjectClass    *gobject_class = (GObjectClass *) class;

	object_class = (GtkObjectClass *) class;

	object_class->destroy = gst_control_destroy;

	gobject_class->finalize = gst_control_finalize;

	widget_class->expose_event = gst_control_expose;

	gst_control_signals [BUTTON_PLAY] =
		g_signal_new ("button_play",
			      G_TYPE_FROM_CLASS (gobject_class),
			      G_SIGNAL_RUN_FIRST,
			      G_STRUCT_OFFSET (GstControlClass, button_play),
			      NULL, NULL,
			      g_cclosure_marshal_VOID__VOID,
			      G_TYPE_NONE, 0);

	gst_control_signals [BUTTON_STOP] =
		g_signal_new ("button_stop",
			      G_TYPE_FROM_CLASS (gobject_class),
			      G_SIGNAL_RUN_FIRST,
			      G_STRUCT_OFFSET (GstControlClass, button_stop),
			      NULL, NULL,
			      g_cclosure_marshal_VOID__VOID,
			      G_TYPE_NONE, 0);
	
	gst_control_signals [BUTTON_NEXT] =
		g_signal_new ("button_next",
			      G_TYPE_FROM_CLASS (gobject_class),
			      G_SIGNAL_RUN_FIRST,
			      G_STRUCT_OFFSET (GstControlClass, button_next),
			      NULL, NULL,
			      g_cclosure_marshal_VOID__VOID,
			      G_TYPE_NONE, 0);

	gst_control_signals [BUTTON_PREV] =
		g_signal_new ("button_prev",
			      G_TYPE_FROM_CLASS (gobject_class),
			      G_SIGNAL_RUN_FIRST,
			      G_STRUCT_OFFSET (GstControlClass, button_prev),
			      NULL, NULL,
			      g_cclosure_marshal_VOID__VOID,
			      G_TYPE_NONE, 0);

	gst_control_signals [BUTTON_LIST] =
		g_signal_new ("button_list",
			      G_TYPE_FROM_CLASS (gobject_class),
			      G_SIGNAL_RUN_FIRST,
			      G_STRUCT_OFFSET (GstControlClass, button_list),
			      NULL, NULL,
			      g_cclosure_marshal_VOID__VOID,
			      G_TYPE_NONE, 0);	

	gst_control_signals [BUTTON_MUTE] =
		g_signal_new ("button_mute",
			      G_TYPE_FROM_CLASS (gobject_class),
			      G_SIGNAL_RUN_FIRST,
			      G_STRUCT_OFFSET (GstControlClass, button_mute),
			      NULL, NULL,
			      g_cclosure_marshal_VOID__VOID,
			      G_TYPE_NONE, 0);	

	gst_control_signals [VOLUME_CHANGE] =
		g_signal_new ("volume_change",
			      G_TYPE_FROM_CLASS (gobject_class),
			      G_SIGNAL_RUN_FIRST,
			      G_STRUCT_OFFSET (GstControlClass, volume_change),
			      NULL, NULL,
			      g_cclosure_marshal_VOID__DOUBLE,
			      G_TYPE_NONE, 1,
			      G_TYPE_DOUBLE);

	gst_control_signals [SEEK_CHANGE] =
		g_signal_new ("seek_change",
			      G_TYPE_FROM_CLASS (gobject_class),
			      G_SIGNAL_RUN_FIRST,
			      G_STRUCT_OFFSET (GstControlClass, seek_change),
			      NULL, NULL,
			      g_cclosure_marshal_VOID__DOUBLE,
			      G_TYPE_NONE, 1,
			      G_TYPE_DOUBLE);

	gst_control_signals [DISPLAY_MODE_CHANGE] =
		g_signal_new ("display_mode_change",
			      G_TYPE_FROM_CLASS (gobject_class),
			      G_SIGNAL_RUN_FIRST,
			      G_STRUCT_OFFSET (GstControlClass, display_mode_change),
			      NULL, NULL,
			      g_cclosure_marshal_VOID__INT,
			      G_TYPE_NONE, 1,
			      G_TYPE_INT);

	class->button_play = NULL;
	class->button_stop = NULL;
	class->button_next = NULL;
	class->button_prev = NULL;
	class->button_list = NULL;
	class->volume_change = NULL;
}

static void
gst_control_instance_init (GstControl *control)
{
	GstControlPrivate  *priv;
	GtkWidget          *image;
	GtkWidget          *button;
	GtkWidget          *hbox;
	GtkWidget          *event_box;
	GtkWidget          *slider;

	control->_priv = g_new0 (GstControlPrivate, 1);
	priv = control->_priv;

	priv->hbox_top = gtk_hbox_new (FALSE, 4);
	priv->hbox_bot = gtk_hbox_new (FALSE, 4);

	gtk_box_pack_start (GTK_BOX (control), priv->hbox_top, TRUE, TRUE, 0);
	gtk_box_pack_start (GTK_BOX (control), priv->hbox_bot, TRUE, TRUE, 0);

	/* top play button */

	priv->image_paused_top = gtk_image_new_from_stock (GST_STOCK_MEDIA_PAUSE, GTK_ICON_SIZE_BUTTON);
	priv->image_playing_top = gtk_image_new_from_stock (GST_STOCK_MEDIA_PLAY, GTK_ICON_SIZE_BUTTON);

	priv->button_play_top = gtk_button_new ();
	hbox = gtk_hbox_new (1, 0);
	gtk_container_add (GTK_CONTAINER (priv->button_play_top), hbox);
	gtk_box_pack_start (GTK_BOX (hbox), priv->image_playing_top, TRUE, TRUE, 0);
	gtk_box_pack_start (GTK_BOX (hbox), priv->image_paused_top, TRUE, TRUE, 0);

	gtk_box_pack_start (GTK_BOX (priv->hbox_top), priv->button_play_top, FALSE, FALSE, 0);
	gtk_button_set_relief (GTK_BUTTON(priv->button_play_top), GTK_RELIEF_NONE);
	g_signal_connect (G_OBJECT (priv->button_play_top), "clicked",
			  G_CALLBACK (gst_control_event_check), control);

	/* seek slider */
	priv->adjustment_seek = G_OBJECT (gtk_adjustment_new (0.0, 0.0, 1.0, 0.1, 0.10, 0.10));
	priv->seek_handle = gtk_hscale_new (GTK_ADJUSTMENT (priv->adjustment_seek));

	gtk_scale_set_draw_value (GTK_SCALE (priv->seek_handle), FALSE);
	gtk_box_pack_start (GTK_BOX (priv->hbox_top), priv->seek_handle, TRUE, TRUE, 0);
	gtk_widget_set_size_request (priv->seek_handle, 280, 17);
	g_signal_connect (GTK_OBJECT (priv->seek_handle), "button_press_event",
			  G_CALLBACK (seek_started), control);
	g_signal_connect (GTK_OBJECT (priv->seek_handle), "button_release_event",
			  G_CALLBACK (seek_changed), control);
	gtk_widget_set_sensitive(priv->seek_handle, FALSE);
	control->_priv->seek_in_progress = FALSE;

	/* top display mode buttons */
	image = gtk_image_new_from_stock (GST_STOCK_DEMAXIMIZE, GTK_ICON_SIZE_BUTTON);
	priv->button_fs_to_normal = gtk_button_new ();
	gtk_container_add (GTK_CONTAINER (priv->button_fs_to_normal), image);
	gtk_box_pack_start (GTK_BOX (priv->hbox_top), priv->button_fs_to_normal, FALSE, FALSE, 0);
	gtk_button_set_relief (GTK_BUTTON(priv->button_fs_to_normal), GTK_RELIEF_NONE);
	g_signal_connect (G_OBJECT (priv->button_fs_to_normal), "clicked",
			  G_CALLBACK (gst_control_event_check), control);
	image = gtk_image_new_from_stock (GST_STOCK_MAXIMIZE, GTK_ICON_SIZE_BUTTON);
	priv->button_mini_to_normal = gtk_button_new ();
	gtk_container_add (GTK_CONTAINER (priv->button_mini_to_normal), image);
	gtk_box_pack_start (GTK_BOX (priv->hbox_top), priv->button_mini_to_normal, FALSE, FALSE, 0);
	gtk_button_set_relief (GTK_BUTTON(priv->button_mini_to_normal), GTK_RELIEF_NONE);
	g_signal_connect (G_OBJECT (priv->button_mini_to_normal), "clicked",
			  G_CALLBACK (gst_control_event_check), control);

	/* stock multimedia buttons */	
	priv->image_paused_bot = gtk_image_new_from_stock (GST_STOCK_MEDIA_PAUSE, GTK_ICON_SIZE_BUTTON);
	priv->image_playing_bot = gtk_image_new_from_stock (GST_STOCK_MEDIA_PLAY, GTK_ICON_SIZE_BUTTON);

	priv->button_play_bot = gtk_button_new ();
	hbox = gtk_hbox_new (1, 0);
	gtk_container_add (GTK_CONTAINER (priv->button_play_bot), hbox);
	gtk_box_pack_start (GTK_BOX (hbox), priv->image_playing_bot, TRUE, TRUE, 0);
	gtk_box_pack_start (GTK_BOX (hbox), priv->image_paused_bot, TRUE, TRUE, 0);

	gtk_box_pack_start (GTK_BOX (priv->hbox_bot), priv->button_play_bot, FALSE, FALSE, 0);
	gtk_button_set_relief (GTK_BUTTON(priv->button_play_bot), GTK_RELIEF_NONE);
	g_signal_connect (G_OBJECT (priv->button_play_bot), "clicked",
			  G_CALLBACK (gst_control_event_check), control);
	
	image = gtk_image_new_from_stock (GST_STOCK_MEDIA_STOP, GTK_ICON_SIZE_BUTTON);
	priv->button_stop = gtk_button_new ();
	gtk_container_add (GTK_CONTAINER (priv->button_stop), image);
	gtk_box_pack_start (GTK_BOX (priv->hbox_bot), priv->button_stop, FALSE, FALSE, 0);
	gtk_button_set_relief (GTK_BUTTON(priv->button_stop), GTK_RELIEF_NONE);
	g_signal_connect (G_OBJECT (priv->button_stop), "clicked",
			  G_CALLBACK (gst_control_event_check), control);

	gtk_box_pack_start (GTK_BOX (priv->hbox_bot), gtk_vseparator_new(), FALSE, FALSE, 0);

	image = gtk_image_new_from_stock (GST_STOCK_MEDIA_PREVIOUS, GTK_ICON_SIZE_BUTTON);
	priv->button_prev = gtk_button_new ();
	gtk_container_add (GTK_CONTAINER (priv->button_prev), image);
	gtk_box_pack_start (GTK_BOX (priv->hbox_bot), priv->button_prev, FALSE, FALSE, 0);
	gtk_button_set_relief (GTK_BUTTON(priv->button_prev), GTK_RELIEF_NONE);
	gtk_widget_set_sensitive(priv->button_prev, FALSE);

	image = gtk_image_new_from_stock (GST_STOCK_MEDIA_NEXT, GTK_ICON_SIZE_BUTTON);
	priv->button_next = gtk_button_new ();
	gtk_container_add (GTK_CONTAINER (priv->button_next), image);
	gtk_box_pack_start (GTK_BOX (priv->hbox_bot), priv->button_next, FALSE, FALSE, 0);
	gtk_button_set_relief (GTK_BUTTON(priv->button_next), GTK_RELIEF_NONE);
	gtk_widget_set_sensitive(priv->button_next, FALSE);
	g_signal_connect (G_OBJECT (priv->button_next), "clicked",
			  G_CALLBACK (gst_control_event_check), control);

	gtk_box_pack_start (GTK_BOX (priv->hbox_bot), gtk_vseparator_new(), FALSE, FALSE, 0);

	/* volume slider */
	priv->image_volume = gtk_image_new_from_stock (GST_STOCK_VOLUME, GTK_ICON_SIZE_BUTTON);
	priv->image_volume_mute = gtk_image_new_from_stock (GST_STOCK_VOLUME_MUTE, GTK_ICON_SIZE_BUTTON);
	
	priv->button_mute = gtk_button_new ();
	hbox = gtk_hbox_new (1, 0);
	gtk_container_add (GTK_CONTAINER (priv->button_mute), hbox);
	gtk_box_pack_start (GTK_BOX (hbox), priv->image_volume, TRUE, TRUE, 0);
	gtk_box_pack_start (GTK_BOX (hbox), priv->image_volume_mute, TRUE, TRUE, 0);

	gtk_box_pack_start (GTK_BOX (priv->hbox_bot), priv->button_mute, FALSE, FALSE, 0);
	gtk_button_set_relief (GTK_BUTTON(priv->button_mute), GTK_RELIEF_NONE);
	g_signal_connect (G_OBJECT (priv->button_mute), "clicked",
			  G_CALLBACK (gst_control_event_check), control);
	
	priv->adjustment_volume = G_OBJECT (gtk_adjustment_new (0.9, 0.0, 1.0, 0.1, 0.10, 0.10));
	priv->hscale_volume = gtk_hscale_new (GTK_ADJUSTMENT (priv->adjustment_volume));
	gtk_scale_set_draw_value (GTK_SCALE (priv->hscale_volume), FALSE);
	gtk_box_pack_start (GTK_BOX (priv->hbox_bot), priv->hscale_volume, FALSE, FALSE, 0);
	gtk_widget_set_size_request (priv->hscale_volume, 80, 17);
	g_signal_connect (G_OBJECT (priv->adjustment_volume), "value_changed",
			  G_CALLBACK (volume_changed), control);

	gtk_box_pack_start (GTK_BOX (priv->hbox_bot), gtk_vseparator_new(), FALSE, FALSE, 0);

	/* playlist button */
	priv->image_playlist = gtk_image_new_from_stock (GST_STOCK_BOOK, GTK_ICON_SIZE_BUTTON);

	priv->button_list = gtk_toggle_button_new ();
	hbox = gtk_hbox_new (1, 0);
	gtk_container_add (GTK_CONTAINER (priv->button_list), hbox);
	gtk_box_pack_start (GTK_BOX (hbox), priv->image_playlist, TRUE, TRUE, 0);

	gtk_box_pack_start (GTK_BOX (priv->hbox_bot), priv->button_list, FALSE, FALSE, 0);
	gtk_button_set_relief (GTK_BUTTON(priv->button_list), GTK_RELIEF_NONE);
	g_signal_connect (G_OBJECT (priv->button_list), "clicked",
			  G_CALLBACK (gst_control_event_check), control);


	/* display mode buttons */
	image = gtk_image_new_from_stock (GST_STOCK_DEMAXIMIZE, GTK_ICON_SIZE_BUTTON);
	priv->button_mini = gtk_button_new ();
	gtk_container_add (GTK_CONTAINER (priv->button_mini), image);
	gtk_box_pack_start (GTK_BOX (priv->hbox_bot), priv->button_mini, FALSE, FALSE, 0);
	gtk_button_set_relief (GTK_BUTTON(priv->button_mini), GTK_RELIEF_NONE);
	g_signal_connect (G_OBJECT (priv->button_mini), "clicked",
			  G_CALLBACK (gst_control_event_check), control);
	image = gtk_image_new_from_stock (GST_STOCK_MAXIMIZE, GTK_ICON_SIZE_BUTTON);
	priv->button_fullscreen = gtk_button_new ();
	gtk_container_add (GTK_CONTAINER (priv->button_fullscreen), image);
	gtk_box_pack_start (GTK_BOX (priv->hbox_bot), priv->button_fullscreen, FALSE, FALSE, 0);
	gtk_button_set_relief (GTK_BUTTON(priv->button_fullscreen), GTK_RELIEF_NONE);
	g_signal_connect (G_OBJECT (priv->button_fullscreen), "clicked",
			  G_CALLBACK (gst_control_event_check), control);
	priv->allow_fullscreen = FALSE;
	gtk_widget_set_sensitive(priv->button_fullscreen, FALSE);
	
	gtk_widget_pop_colormap ();

	gtk_widget_show_all (priv->hbox_top);
	gtk_widget_show_all (priv->hbox_bot);
	gtk_widget_hide(priv->image_paused_bot);
	gtk_widget_hide(priv->image_paused_top);
	gtk_widget_hide(priv->image_volume_mute);
	gst_control_set_display_mode(control, GST_MEDIA_PLAY_NORMAL);
}

static void
gst_control_destroy (GtkObject *object)
{
	GstControl *control;

	g_return_if_fail (GST_IS_CONTROL (object));

	control = GST_CONTROL (object);

	GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
}

static void
gst_control_finalize (GObject *object)
{
	GstControl *control;

	g_return_if_fail (GST_IS_CONTROL (object));

	control = GST_CONTROL (object);

	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
}

static gint
gst_control_expose (GtkWidget  *widget, GdkEventExpose *event)
{
	GstControl *control;
	g_return_val_if_fail (GST_IS_CONTROL (widget), FALSE);
	g_return_val_if_fail (event != NULL, FALSE);

	control = GST_CONTROL(widget);

	if (GTK_WIDGET_DRAWABLE (widget)) {
		return GNOME_CALL_PARENT_WITH_DEFAULT
			(GTK_WIDGET_CLASS, expose_event, (widget, event), FALSE);
	}

	return FALSE;
}

GtkWidget *
gst_control_new (void)
{
	GstControl *control;

	control = g_object_new (GST_TYPE_CONTROL, NULL);

	return GTK_WIDGET (control);
}

void
gst_control_set_display_mode  (GstControl *control, GstMediaPlayMode display_mode)
{
	GstControlPrivate  *priv;
	g_return_if_fail (GST_IS_CONTROL (control));

	priv = control->_priv;

	if (display_mode == GST_MEDIA_PLAY_NORMAL){
		gtk_widget_show (priv->hbox_bot);
		gtk_widget_show (priv->button_mini);
		gtk_widget_show (priv->button_fullscreen);
		gtk_widget_set_sensitive(priv->button_fullscreen, priv->allow_fullscreen);

		gtk_widget_hide (priv->button_play_top);
		gtk_widget_hide (priv->button_fs_to_normal);
		gtk_widget_hide (priv->button_mini_to_normal);
	}
	else if (display_mode == GST_MEDIA_PLAY_FULLSCREEN){
		gtk_widget_hide (priv->hbox_bot);
		gtk_widget_hide (priv->button_mini_to_normal);

		gtk_widget_show (priv->button_play_top);
		gtk_widget_show (priv->button_fs_to_normal);
	}
	else {
		gtk_widget_hide (priv->hbox_bot);
		gtk_widget_hide (priv->button_fs_to_normal);

		gtk_widget_show (priv->button_play_top);
		gtk_widget_show (priv->button_mini_to_normal);
	}


	priv->display_mode = display_mode;
}

void
gst_control_set_state  (GstControl *control, GstElementState state)
{
	g_return_if_fail (GST_IS_CONTROL (control));
	if (state == GST_STATE_PLAYING){
		gtk_widget_show(control->_priv->image_paused_bot);
		gtk_widget_show(control->_priv->image_paused_top);
		gtk_widget_hide(control->_priv->image_playing_bot);
		gtk_widget_hide(control->_priv->image_playing_top);
	}
	else {
		gtk_widget_hide(control->_priv->image_paused_bot);
		gtk_widget_hide(control->_priv->image_paused_top);
		gtk_widget_show(control->_priv->image_playing_bot);
		gtk_widget_show(control->_priv->image_playing_top);
	}
}

GtkAdjustment*
gst_control_get_volume_adjustment (GstControl *control)
{
	g_return_if_fail (GST_IS_CONTROL (control));
	return GTK_ADJUSTMENT(control->_priv->adjustment_volume);

}

void
gst_control_set_mute  (GstControl *control, gboolean mute)
{
	g_return_if_fail (GST_IS_CONTROL (control));
	if (mute){
		gtk_widget_hide(control->_priv->image_volume);
		gtk_widget_show(control->_priv->image_volume_mute);
	}
	else {
		gtk_widget_hide(control->_priv->image_volume_mute);
		gtk_widget_show(control->_priv->image_volume);
	}
}

void
gst_control_set_enable_seek (GstControl* control, gboolean enable)
{
	g_return_if_fail (GST_IS_CONTROL (control));
	gtk_widget_set_sensitive(control->_priv->seek_handle, enable);
	gtk_adjustment_set_value(GTK_ADJUSTMENT(control->_priv->adjustment_seek), 0.0);
}

void
gst_control_allow_fullscreen (GstControl* control, gboolean allow)
{
	g_return_if_fail (GST_IS_CONTROL (control));
	control->_priv->allow_fullscreen = allow;
	if (control->_priv->display_mode == GST_MEDIA_PLAY_NORMAL){
		gtk_widget_set_sensitive(control->_priv->button_fullscreen, allow);
	}
}

void
gst_control_playlist_is_open (GstControl* control, gboolean is_open)
{
	g_return_if_fail (GST_IS_CONTROL (control));
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(control->_priv->button_list), is_open);
}

void
gst_control_set_seek_pos (GstControl* control, gdouble seek_pos)
{
	g_return_if_fail (GST_IS_CONTROL (control));

	if (control->_priv->seek_in_progress == FALSE){
		gtk_adjustment_set_value(GTK_ADJUSTMENT(control->_priv->adjustment_seek), seek_pos);
	}
}
